@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '1.19';
+our $VERSION = '1.20';
 
 use File::Which qw( which );
 
@@ -27,14 +27,6 @@ has wall_min_perl_version => (
     default => '5.008008',
 );
 
-with 'Dist::Zilla::Plugin::DROLSKY::Role::CoreCounter';
-
-# Dist::Zilla provides no way to pass a `-j` option when running dzil release
-# but I really would like faster releases.
-sub default_jobs {
-    return shift->_core_count;
-}
-
 override _build_WriteMakefile_dump => sub {
     my $self = shift;
 
@@ -69,7 +61,7 @@ Dist::Zilla::Plugin::DROLSKY::MakeMaker - Subclasses MakeMaker::Awesome to alway
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =for Pod::Coverage .*
 
@@ -77,8 +69,6 @@ version 1.19
 
 Bugs may be submitted at L<https://github.com/autarch/Dist-Zilla-PluginBundle-DROLSKY/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Dist-Zilla-PluginBundle-DROLSKY can be found at L<https://github.com/autarch/Dist-Zilla-PluginBundle-DROLSKY>.
