@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean -also => ['_exp'];
 
-our $VERSION = '1.19';
+our $VERSION = '1.20';
 
 use Dist::Zilla::Plugin::PodWeaver;
 use List::Util qw( first );
@@ -140,35 +140,6 @@ join "\n\n", (
             . $distmeta->{resources}{x_MailingList} . '>.'
         : (),
     ),
-    (
-        $distmeta->{resources}{x_IRC}
-        ? 'This distribution also has an IRC channel at' . "\nL<" . do {
-
-            # try to extract the channel
-            if (
-                my ( $network, $channel ) = (
-                    $distmeta->{resources}{x_IRC}
-                        =~ m!(?:://)?(\w+(?:\.\w+)*)/?(#\w+)!
-                )
-                ) {
-                'C<'
-                    . $channel
-                    . '> on C<'
-                    . $network . '>|'
-                    . $distmeta->{resources}{x_IRC};
-            }
-            else {
-                $distmeta->{resources}{x_IRC};
-            }
-            }
-            . '>.'
-        : (),
-    ),
-    (
-        ( $distmeta->{x_authority} // '' ) eq 'cpan:DROLSKY'
-        ? q{I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.}
-        : (),
-    ),
     )
 }}
 SUPPORT
@@ -322,7 +293,7 @@ Pod::Weaver::PluginBundle::DROLSKY - A plugin bundle for pod woven by DROLSKY
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 SYNOPSIS
 
@@ -502,8 +473,6 @@ L<Dist::Zilla::PluginBundle::DROLSKY>
 
 Bugs may be submitted at L<https://github.com/autarch/Dist-Zilla-PluginBundle-DROLSKY/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Dist-Zilla-PluginBundle-DROLSKY can be found at L<https://github.com/autarch/Dist-Zilla-PluginBundle-DROLSKY>.
